@@ -21,9 +21,9 @@ class catch_integrity_error(contextlib.ContextDecorator):
     def __exit__(self, exc_type, exc_value, traceback):
         if exc_type and issubclass(exc_type, sqla.exc.IntegrityError):
             if isinstance(exc_value.orig, ppe.UniqueViolation):
-                abort(409, "Unique constraint violation")
+                abort(409, message="Unique constraint violation")
             if isinstance(exc_value.orig, ppe.ForeignKeyViolation):
-                abort(409, "Foreign key constraint violation")
+                abort(409, message="Foreign key constraint violation")
             # Shouldn't happen
             abort(409)
         return False
