@@ -2,13 +2,13 @@
 import marshmallow as ma
 
 from bemserver_api import Schema
-from bemserver_api.extensions.ma_fields import Timezone
+from bemserver_api.extensions import ma_fields
 from bemserver_api.resources.timeseries_data.schemas import TimeseriesBucketWidthSchema
 
 
 class EnergyConsumptionSchema(Schema):
     timestamps = ma.fields.List(
-        ma.fields.AwareDateTime,
+        ma_fields.AwareDateTime,
         metadata={
             "description": "Time index (value is bucket start time)",
         },
@@ -25,19 +25,19 @@ class EnergyConsumptionSchema(Schema):
 
 
 class EnergyConsumptionQueryArgsSchema(TimeseriesBucketWidthSchema):
-    start_time = ma.fields.AwareDateTime(
+    start_time = ma_fields.AwareDateTime(
         required=True,
         metadata={
             "description": "Initial datetime",
         },
     )
-    end_time = ma.fields.AwareDateTime(
+    end_time = ma_fields.AwareDateTime(
         required=True,
         metadata={
             "description": "End datetime (excluded from the interval)",
         },
     )
-    timezone = Timezone(
+    timezone = ma_fields.Timezone(
         load_default="UTC",
         metadata={
             "description": "Timezone to use for the aggreagation",
