@@ -5,6 +5,7 @@ import marshmallow_sqlalchemy as msa
 from bemserver_core.model import WeatherParameterEnum, WeatherTimeseriesBySite
 
 from bemserver_api import AutoSchema, Schema
+from ..timeseries.schemas import TimeseriesSchema
 
 
 class WeatherTimeseriesBySiteSchema(AutoSchema):
@@ -13,6 +14,7 @@ class WeatherTimeseriesBySiteSchema(AutoSchema):
 
     id = msa.auto_field(dump_only=True)
     parameter = ma.fields.Enum(WeatherParameterEnum)
+    timeseries = ma.fields.Nested(TimeseriesSchema(exclude=("id",)), dump_only=True)
 
 
 class WeatherTimeseriesBySiteQueryArgsSchema(Schema):
